#ifndef CONNECTIONDIALOG_H
#define CONNECTIONDIALOG_H

#include <QDialog>
#include <QtDebug>
#include "ui_connectionDialog.h"
#include "usersettings.h"

namespace Ui {
    class connectionDialog;
}


class connectionDialog : public QDialog
{
    Q_OBJECT

public:
    explicit connectionDialog(QWidget *parent = 0,UserSettings oldSettings=UserSettings());
    ~connectionDialog();

signals:
    void connectionSettingsUpdated(UserSettings settings);
    void constructWolDialog(UserSettings settings);

private:
    Ui::connectionDialog *ui;
    UserSettings settings;
    QString wolMac_i;
    quint16 wolPort_i;

private slots:
    void on_buttonBox_rejected();
    void on_buttonBox_accepted();
    void on_wolPushButton_clicked();

};

#endif // CONNECTIONDIALOG_H
